Documentation
¶
Overview ¶
Package random provides utilities for generating random strings and numbers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Base64Bytes ¶
Base64Bytes returns n cryptographically-random bytes encoded as standard base64 (with padding). Used for ss2022 keys, which xray expects as a base64-encoded key of a specific byte length per cipher.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.